@@ -34,7 +34,7 @@
  -----------------------------------------------------------------------------*/
 
 #include <cpl.h>
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_alloc.h"
 
 /*----------------------------------------------------------------------------*/
