@@ -40,9 +40,9 @@
 
 #include "hawki_distortion.h"
 #include "hawki_bkg.h"
-#include "hawki_pfits.h"
+#include "hawki_pfits_legacy.h"
 #include "hawki_load.h"
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_image.h"
 
 /*----------------------------------------------------------------------------*/
@@ -561,6 +561,7 @@ int hawki_bkg_set_obj_mask
     
     cpl_image_delete(mask_intersection);
     cpl_mask_delete(mask_final);
+    return 0;
 }
 
 /**@}*/
