@@ -38,9 +38,9 @@
 #include <math.h>
 #include <cpl.h>
 
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_calib.h"
-#include "hawki_pfits.h"
+#include "hawki_pfits_legacy.h"
 #include "hawki_load.h"
 
 /*----------------------------------------------------------------------------*/
