@@ -47,8 +47,8 @@
 #endif
 
 #include "hawki_distortion.h"
-#include "hawki_dfs.h"
-#include "hawki_utils.h"
+#include "hawki_dfs_legacy.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_load.h"
 
 
