@@ -37,8 +37,8 @@
 #include <cpl.h>
 
 #include "hawki_image_stats.h"
-#include "hawki_dfs.h"
-#include "hawki_utils.h"
+#include "hawki_dfs_legacy.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_load.h"
 
 /*----------------------------------------------------------------------------*/
