@@ -26,12 +26,13 @@
  -----------------------------------------------------------------------------*/
 
 #include <string.h>
+#include <locale.h>
 #include <cpl.h>
 
 #include "hawki_load.h"
-#include "hawki_pfits.h"
-#include "hawki_utils.h"
-#include "hawki_dfs.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_utils_legacy.h"
+#include "hawki_dfs_legacy.h"
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -821,6 +822,7 @@ int hawki_get_detector_from_ext(
     plist=cpl_propertylist_load(fname, ext) ;
     if (plist == NULL) return -1 ;
     sval = hawki_pfits_get_extname(plist) ;
+    setlocale(LC_NUMERIC, "C"); // Behaviour of sscanf depends on the locale
     if (sscanf(sval, "CHIP%d.INT1", &chip) != 1) chip = -1 ;
     cpl_propertylist_delete(plist) ;
 
