@@ -1,4 +1,4 @@
-/* $Id: irplib_plugin.c,v 1.39 2012/02/03 14:19:06 llundin Exp $
+/* $Id: irplib_plugin.c,v 1.40 2013-08-22 17:44:56 cgarcia Exp $
  *
  * This file is part of the irplib package 
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2012/02/03 14:19:06 $
- * $Revision: 1.39 $
- * $Name: hawki-1_8_12 $
+ * $Author: cgarcia $
+ * $Date: 2013-08-22 17:44:56 $
+ * $Revision: 1.40 $
+ * $Name: not supported by cvs2svn $
  */
 
 /*-----------------------------------------------------------------------------
@@ -765,7 +765,9 @@ static void recipe_sof_test_image_empty(cpl_plugin * plugin, size_t nstr,
 
     for (i = 0; i < nstr; i++) {
         cpl_frame * f = cpl_frame_new();
-        char * rawname = cpl_sprintf("raw%05u.fits", (unsigned)(i+1));
+        char * rawname = cpl_sprintf("%s-raw%05u.fits",
+                                     cpl_plugin_get_name(plugin),
+                                     (unsigned)(i+1));
 
         error = cpl_image_save(iempty, rawname,CPL_BPP_IEEE_FLOAT, NULL,
                                CPL_IO_DEFAULT);
@@ -851,7 +853,7 @@ cpl_boolean irplib_plugin_has_sof_from_env(const cpl_plugin * plugin,
     frames = cpl_frameset_new();
     recipe_frameset_load(frames, sof_name);
 
-    ffirst = cpl_frameset_get_first_const(frames);
+    ffirst = cpl_frameset_get_position_const(frames, 0);
 
     cpl_free(sof_name);
     cpl_frameset_delete(frames);
@@ -1023,13 +1025,16 @@ static void recipe_frameset_load(cpl_frameset * set, const char *name)
     /* Loop over all the lines in the set-of-frames file */
     for (line_number = 0; fgets(line, LINE_LEN_MAX - 1, fp); line_number++) {
 
+        char scan_fmt[50];
         cpl_frame_group grp;
         cpl_frame * frame;
         int n;
 
         if (line[0] == '#') continue;
 
-        n = sscanf(line, "%s %s %s", path, tag, group);
+        snprintf(scan_fmt, 49, "%%%ds %%%ds %%%ds", LINE_LEN_MAX - 1,
+                 LINE_LEN_MAX - 1, LINE_LEN_MAX - 1); 
+        n = sscanf(line, scan_fmt, path, tag, group);
 
         if (n < 1) {
             cpl_msg_warning(cpl_func, "Spurious line no. %d in %s: %s",
