@@ -40,13 +40,13 @@
 #include "irplib_utils.h"
 
 #include "hawki_alloc.h"
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_calib.h"
 #include "hawki_distortion.h"
 #include "hawki_load.h"
 #include "hawki_save.h"
-#include "hawki_pfits.h"
-#include "hawki_dfs.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_dfs_legacy.h"
 #include "irplib_cat.h"
 #include "irplib_stdstar.h"
 #include "irplib_match_cats.h"
@@ -56,10 +56,6 @@
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C"
-#endif
-int cpl_plugin_get_info(cpl_pluginlist * list);
 
 static int hawki_cal_distortion_create(cpl_plugin *) ;
 static int hawki_cal_distortion_exec(cpl_plugin *) ;
@@ -150,7 +146,7 @@ static struct
 } hawki_cal_distortion_config;
 
 static char hawki_cal_distortion_description[] = 
-"hawki_cal_distortion -- HAWK-I distortion and astrometry autocalibration.\n\n"
+"(OBSOLETE) hawki_cal_distortion -- HAWK-I distortion and astrometry autocalibration.\n\n"
 "The input files must be tagged:\n"
 "distortion_field.fits "HAWKI_CAL_DISTOR_RAW"\n"
 "sky_distortion.fits "HAWKI_CAL_DISTOR_SKY_RAW"\n"
@@ -190,11 +186,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_cal_distortion",
-                    "Distortion autocalibration",
+                    "(OBSOLETE) Distortion autocalibration",
                     hawki_cal_distortion_description,
-                    "Cesar Enrique Garcia Dabo",
+                    "ESO Pipeline Group",
                     PACKAGE_BUGREPORT,
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_cal_distortion_create,
                     hawki_cal_distortion_exec,
                     hawki_cal_distortion_destroy);
@@ -350,7 +346,7 @@ static int hawki_cal_distortion(cpl_parameterlist *   parlist,
     }
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(frameset)) {
+    if (hawki_dfs_set_groups_legacy(frameset)) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         return -1 ;
     }
@@ -628,7 +624,7 @@ static int hawki_cal_distortion_get_apertures_from_raw_distor
             cpl_imagelist_delete(dark_images);
             return -1;
         }
-        science_dit = hawki_pfits_get_dit(plist);
+        science_dit = hawki_pfits_get_dit_legacy(plist);
         cpl_imagelist_multiply_scalar(dark_images, science_dit);
         cpl_propertylist_delete(plist);
     }
@@ -767,7 +763,7 @@ static cpl_image **  hawki_cal_distortion_get_master_sky
             cpl_imagelist_delete(bpm_images);
             return NULL;
         }
-        science_dit = hawki_pfits_get_dit(plist);
+        science_dit = hawki_pfits_get_dit_legacy(plist);
         cpl_imagelist_multiply_scalar(dark_images, science_dit);
         cpl_propertylist_delete(plist);
     }
