@@ -34,17 +34,18 @@
  -----------------------------------------------------------------------------*/
 
 #include <math.h>
+#include <locale.h>
 #include <string.h>
 #include <cpl.h>
 
 #include "irplib_utils.h"
 
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_image_stats.h"
 #include "hawki_load.h"
 #include "hawki_save.h"
-#include "hawki_pfits.h"
-#include "hawki_dfs.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_dfs_legacy.h"
 
 /*-----------------------------------------------------------------------------
                             Functions prototypes
@@ -136,7 +137,7 @@ static struct {
 } hawki_cal_flat_outputs;
 
 static char hawki_cal_flat_description[] = 
-"hawki_cal_flat -- HAWKĪI imaging flat-field creation from twillight images.\n"
+"(OBSOLETE) hawki_cal_flat -- HAWKĪI imaging flat-field creation from twillight images.\n"
 "The input of the recipe files listed in the Set Of Frames (sof-file)\n"
 "must be tagged as:\n"
 "raw-file.fits "HAWKI_CAL_FLAT_RAW" or\n"
@@ -186,11 +187,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_cal_flat",
-                    "Twillight flat recipe",
+                    "(OBSOLETE) Twillight flat recipe",
                     hawki_cal_flat_description,
-                    "Cesar Enrique Garcia Dabo",
+                    "ESO Pipeline Group",
                     PACKAGE_BUGREPORT,  
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_cal_flat_create,
                     hawki_cal_flat_exec,
                     hawki_cal_flat_destroy) ;
@@ -424,7 +425,7 @@ static int hawki_cal_flat(
     }
     
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(framelist)) {
+    if (hawki_dfs_set_groups_legacy(framelist)) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         return -1;
     }
@@ -879,7 +880,7 @@ static cpl_imagelist ** hawki_cal_flat_reduce(
                     cpl_image_delete(dark);
                     return NULL ;
                 }
-                flat_dit = hawki_pfits_get_dit(plist);
+                flat_dit = hawki_pfits_get_dit_legacy(plist);
                 cpl_image_multiply_scalar(dark, flat_dit);
                 cpl_propertylist_delete(plist);
 
@@ -1533,8 +1534,8 @@ static int hawki_cal_flat_compare(
     comparison = 1 ;
 
     /* Compare filters */
-    sval1 = hawki_pfits_get_filter(plist1) ;
-    sval2 = hawki_pfits_get_filter(plist2) ;
+    sval1 = hawki_pfits_get_filter_legacy(plist1) ;
+    sval2 = hawki_pfits_get_filter_legacy(plist2) ;
     if (cpl_error_get_code()) {
         cpl_msg_error(__func__, "cannot get the filter");
         cpl_propertylist_delete(plist1) ;
@@ -1544,8 +1545,8 @@ static int hawki_cal_flat_compare(
     if (strcmp(sval1, sval2)) comparison = 0 ;
 
     /* Compare DITs */
-    dval1 = hawki_pfits_get_dit(plist1) ;
-    dval2 = hawki_pfits_get_dit(plist2) ;
+    dval1 = hawki_pfits_get_dit_legacy(plist1) ;
+    dval2 = hawki_pfits_get_dit_legacy(plist2) ;
     if (cpl_error_get_code()) {
         cpl_msg_error(__func__, "cannot get the DIT");
         cpl_propertylist_delete(plist1) ;
@@ -1843,6 +1844,7 @@ static int hawki_cal_flat_retrieve_input_param
     /* Retrieve input parameters */
     par = cpl_parameterlist_find(parlist, "hawki.hawki_cal_flat.zone") ;
     sval = cpl_parameter_get_string(par) ;
+    setlocale(LC_NUMERIC, "C"); // Behaviour of sscanf depends on the locale
     if (sscanf(sval, "%d,%d,%d,%d",
                     &hawki_cal_flat_config.llx,
                     &hawki_cal_flat_config.lly,
