@@ -34,18 +34,19 @@
  -----------------------------------------------------------------------------*/
 
 #include <math.h>
+#include <locale.h>
 #include <cpl.h>
 #include <string.h>
 
 #include "irplib_utils.h"
 #include "irplib_calib.h"
 
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_calib.h"
 #include "hawki_load.h"
 #include "hawki_save.h"
-#include "hawki_pfits.h"
-#include "hawki_dfs.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_dfs_legacy.h"
 #include "hawki_saa.h"
 #include "hawki_bkg.h"
 #include "hawki_distortion.h"
@@ -64,11 +65,6 @@
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C"
-#endif
-int cpl_plugin_get_info(cpl_pluginlist * list);
-
 static int hawki_sci_jitter_create(cpl_plugin *) ;
 static int hawki_sci_jitter_exec(cpl_plugin *) ;
 static int hawki_sci_jitter_destroy(cpl_plugin *) ;
@@ -175,7 +171,7 @@ static struct
 } hawki_sci_jitter_output;
 
 static char hawki_sci_jitter_description[] =
-"hawki_sci_jitter -- hawki imaging jitter recipe.\n\n"
+"(OBSOLETE) hawki_sci_jitter -- hawki imaging jitter recipe.\n\n"
 "The input of the recipe files listed in the Set Of Frames (sof-file)\n"
 "must be tagged as:\n"
 "raw-file.fits "HAWKI_IMG_JITTER_RAW" or\n"
@@ -227,11 +223,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_sci_jitter",
-                    "Jitter recipe",
+                    "(OBSOLETE) Jitter recipe",
                     hawki_sci_jitter_description,
-                    "Cesar Enrique Garcia",
+                    "ESO Pipeline Group",
                     PACKAGE_BUGREPORT,
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_sci_jitter_create,
                     hawki_sci_jitter_exec,
                     hawki_sci_jitter_destroy) ;
@@ -460,7 +456,7 @@ static int hawki_sci_jitter(
     }
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(framelist)) {
+    if (hawki_dfs_set_groups_legacy(framelist)) {
         cpl_msg_error(cpl_func, "Cannot identify RAW and CALIB frames") ;
         cpl_frameset_delete(calib_frames);
         return -1 ;
@@ -714,6 +710,7 @@ int hawki_sci_jitter_retrieve_input_param
     hawki_sci_jitter_config.offset_max = cpl_parameter_get_int(par);
     par = cpl_parameterlist_find(parlist, "hawki.hawki_sci_jitter.sky_par");
     sval = cpl_parameter_get_string(par);
+    setlocale(LC_NUMERIC, "C"); // Behaviour of sscanf depends on the locale
     if (sscanf(sval, "%d,%d,%d,%d",
                &hawki_sci_jitter_config.sky_minnb,
                &hawki_sci_jitter_config.sky_halfw,
@@ -803,7 +800,7 @@ static cpl_image ** hawki_sci_jitter_reduce
     frame = cpl_frameset_get_position(jitters, 0) ;
     plist=cpl_propertylist_load(cpl_frame_get_filename(frame), 0) ;
     hawki_sci_jitter_output.pixscale = hawki_pfits_get_pixscale(plist) ;
-    hawki_sci_jitter_output.dit = hawki_pfits_get_dit(plist) ;
+    hawki_sci_jitter_output.dit = hawki_pfits_get_dit_legacy(plist) ;
     cpl_propertylist_delete(plist) ;
     if (cpl_error_get_code()) {
         cpl_msg_error(cpl_func, "Missing keyword in FITS header") ;
@@ -811,8 +808,8 @@ static cpl_image ** hawki_sci_jitter_reduce
     }
 
     /* Check that DIT/NDIT and NDSAMPLES are the same for all the frames */
-    if(!hawki_utils_check_equal_double_keys(jitters, &hawki_pfits_get_dit) ||
-       !hawki_utils_check_equal_int_keys(jitters, &hawki_pfits_get_ndit)||
+    if(!hawki_utils_check_equal_double_keys(jitters, &hawki_pfits_get_dit_legacy) ||
+       !hawki_utils_check_equal_int_keys(jitters, &hawki_pfits_get_ndit_legacy)||
        !hawki_utils_check_equal_int_keys(jitters, &hawki_pfits_get_ndsamples))
     {
         cpl_msg_error(__func__, "Not all input science have the same "
@@ -2107,7 +2104,7 @@ static int hawki_sci_jitter_save
     cpl_free(qclists) ;
     if(!cpl_errorstate_is_equal(error_prevstate))
     {
-        cpl_errorstate_set(CPL_ERROR_NONE);
+        cpl_error_reset();
         return -1;
     }
     return  0;
@@ -2149,7 +2146,7 @@ int hawki_sci_jitter_whole_image_algo
         {
             cpl_msg_warning(cpl_func,"Some telescope properties could not be "
                             "read for image %d", iframe+1);
-            cpl_errorstate_set(CPL_ERROR_NONE);
+            cpl_error_reset();
         }
         cpl_propertylist_delete(this_properties);
     }
@@ -2243,7 +2240,7 @@ int hawki_sci_jitter_save_stats
     cpl_free(qcstats);
     if(!cpl_errorstate_is_equal(error_prevstate))
     {
-        cpl_errorstate_set(CPL_ERROR_NONE);
+        cpl_error_reset();
         return -1;
     }
         
