@@ -1,4 +1,4 @@
-/* $Id: hawki_step_compute_bkg.cc,v 1.6 2013/01/29 18:16:21 cgarcia Exp $
+/* $Id: hawki_step_compute_bkg.cc,v 1.9 2013-09-02 14:30:55 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2008 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2013/01/29 18:16:21 $
- * $Revision: 1.6 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-09-02 14:30:55 $
+ * $Revision: 1.9 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,12 +37,12 @@
 #include <math.h>
 #include <cpl.h>
 
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_distortion.h"
 #include "hawki_load.h"
 #include "hawki_save.h"
-#include "hawki_pfits.h"
-#include "hawki_dfs.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_dfs_legacy.h"
 #include "hawki_bkg.h"
 #include "hawki_calib.h"
 #include "hawki_image.h"
@@ -65,11 +65,6 @@ static struct
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C"
-#endif
-int cpl_plugin_get_info(cpl_pluginlist * list);
-
 static int hawki_step_compute_bkg_create(cpl_plugin *) ;
 static int hawki_step_compute_bkg_exec(cpl_plugin *) ;
 static int hawki_step_compute_bkg_destroy(cpl_plugin *) ;
@@ -138,20 +133,20 @@ int hawki_step_compute_bkg_get_inverse_dist
 
 
 static char hawki_step_compute_bkg_description[] =
-"hawki_step_compute_bkg -- hawki background computation utility.\n"
+"(OBSOLETE) hawki_step_compute_bkg -- hawki background computation utility.\n"
 "This recipe will create the associated background images\n"
 "for a given set of object images. If there are sky images, these will\n"
 "be used to compute the background, otherwise, the background is computed\n"
 "using a running mean on the object images. An optional mask can be supplied\n"
 "for the running mean.\n"
 "The files listed in the Set Of Frames (sof-file) must be tagged:\n"
-"obj_basic_cal-file.fits "HAWKI_CALPRO_BASICCALIBRATED" or\n"
-"sky_basic_cal-file.fits "HAWKI_CALPRO_SKY_BASICCALIBRATED" \n"
+"obj_basic_cal-file.fits " HAWKI_CALPRO_BASICCALIBRATED " or\n"
+"sky_basic_cal-file.fits " HAWKI_CALPRO_SKY_BASICCALIBRATED " \n"
 "and optionally for object masking:\n"
-"object_mask-file.fits "HAWKI_CALPRO_OBJ_MASK" \n"
-"offsets.fits "HAWKI_CALPRO_OFFSETS" \n"
-"distortion_x.fits "HAWKI_CALPRO_DISTORTION_X" \n"
-"distortion_y.fits "HAWKI_CALPRO_DISTORTION_Y" \n";
+"object_mask-file.fits " HAWKI_CALPRO_OBJ_MASK " \n"
+"offsets.fits " HAWKI_CALPRO_OFFSETS " \n"
+"distortion_x.fits " HAWKI_CALPRO_DISTORTION_X " \n"
+"distortion_y.fits " HAWKI_CALPRO_DISTORTION_Y " \n";
 
 /*-----------------------------------------------------------------------------
                                 Functions code
@@ -176,11 +171,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_step_compute_bkg",
-                    "Background computing utility",
+                    "(OBSOLETE) Background computing utility",
                     hawki_step_compute_bkg_description,
-                    "Cesar Enrique Garcia Dabo",
+                    "ESO Pipeline Group",
                     PACKAGE_BUGREPORT,  
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_step_compute_bkg_create,
                     hawki_step_compute_bkg_exec,
                     hawki_step_compute_bkg_destroy);
@@ -355,7 +350,7 @@ static int hawki_step_compute_bkg(
     }   
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(framelist)) 
+    if (hawki_dfs_set_groups_legacy(framelist)) 
     {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         return -1 ;
@@ -632,7 +627,7 @@ static int hawki_step_compute_bkg_from_objects_running_median_save
         
         cpl_msg_info(__func__,"Using masked objects");
 
-        maskframe = cpl_frameset_get_first(maskframes);
+        maskframe = cpl_frameset_get_position(maskframes, 0);
         if(distortionframes_x == NULL && distortionframes_y == NULL )
         {
             distortionframe_x = NULL;
@@ -640,8 +635,8 @@ static int hawki_step_compute_bkg_from_objects_running_median_save
         }
         else
         {
-            distortionframe_x = cpl_frameset_get_first(distortionframes_x);
-            distortionframe_y = cpl_frameset_get_first(distortionframes_y);
+            distortionframe_x = cpl_frameset_get_position(distortionframes_x, 0);
+            distortionframe_y = cpl_frameset_get_position(distortionframes_y, 0);
         }
         
         /* Get the offsets */
@@ -673,7 +668,7 @@ static int hawki_step_compute_bkg_from_objects_running_median_save
         {
             cpl_msg_info(__func__,"Using refined offsets");
             offsets = hawki_load_refined_offsets
-                (cpl_frameset_get_first(offsetframes));
+                (cpl_frameset_get_position(offsetframes, 0));
             if(offsets == NULL)
             {
                 cpl_msg_error(__func__, "Cannot load the refined offsets");
@@ -736,7 +731,7 @@ int hawki_step_compute_bkg_from_running_median_nonmasked_save
         const cpl_frame      * target_frame;
         char filename[256];
         snprintf(filename, 256, "hawki_step_compute_bkg_%04d.fits", iobj + 1);
-        target_frame = cpl_frameset_get_frame_const(objframes, iobj);
+        target_frame = cpl_frameset_get_position_const(objframes, iobj);
         used_frameset = cpl_frameset_new();
         cpl_frameset_insert(used_frameset, cpl_frame_duplicate(target_frame));
         hawki_frameset_append(used_frameset, objframes);
@@ -774,7 +769,7 @@ int hawki_step_compute_bkg_from_running_median_nonmasked_save
 
         /* Get the size of the bkg */
         img_ref = hawki_load_frame_extension
-            (cpl_frameset_get_first_const(objframes), iext + 1, CPL_TYPE_FLOAT);
+            (cpl_frameset_get_position_const(objframes, 0), iext + 1, CPL_TYPE_FLOAT);
         nx = cpl_image_get_size_x(img_ref);
         ny = cpl_image_get_size_y(img_ref);
         cpl_image_delete(img_ref);
@@ -892,7 +887,7 @@ int hawki_step_compute_bkg_from_running_median_masked_save
         const cpl_frame      * target_frame;
         char filename[256];
         snprintf(filename, 256, "hawki_step_compute_bkg_%04d.fits", iobj + 1);
-        target_frame = cpl_frameset_get_frame_const(objframes, iobj);
+        target_frame = cpl_frameset_get_position_const(objframes, iobj);
         used_frameset = cpl_frameset_new();
         cpl_frameset_insert(used_frameset, cpl_frame_duplicate(target_frame));
         hawki_frameset_append(used_frameset, objframes);
@@ -943,7 +938,7 @@ int hawki_step_compute_bkg_from_running_median_masked_save
         
         /* Get the size of the bkg */
         img_ref = hawki_load_frame_extension
-            (cpl_frameset_get_first_const(objframes), iext + 1, CPL_TYPE_FLOAT);
+            (cpl_frameset_get_position_const(objframes, 0), iext + 1, CPL_TYPE_FLOAT);
         nx = cpl_image_get_size_x(img_ref);
         ny = cpl_image_get_size_y(img_ref);
         cpl_image_delete(img_ref);
