@@ -34,14 +34,15 @@
  -----------------------------------------------------------------------------*/
 
 #include <math.h>
+#include <locale.h>
 #include <cpl.h>
 
 #include "irplib_utils.h"
 
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_load.h"
-#include "hawki_pfits.h"
-#include "hawki_dfs.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_dfs_legacy.h"
 #include "hawki_distortion.h"
 #include "hawki_save.h"
 
@@ -49,11 +50,6 @@
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C"
-#endif
-int cpl_plugin_get_info(cpl_pluginlist * list);
-
 static int hawki_util_gendist_create(cpl_plugin *) ;
 static int hawki_util_gendist_exec(cpl_plugin *) ;
 static int hawki_util_gendist_destroy(cpl_plugin *) ;
@@ -69,7 +65,7 @@ static hawki_distortion * hawki_util_gendist_convert_to_images
  -----------------------------------------------------------------------------*/
 
 static char hawki_util_gendist_description[] = 
-"hawki_util_gendist -- HAWK-I distortion calibration file creation.\n"
+"(OBSOLETE) hawki_util_gendist -- HAWK-I distortion calibration file creation.\n"
 "The 4 files (chip 1 2 3 4) listed in the Set Of Frames (sof-file) \n"
 "must be tagged:\n"
 "raw-file_chip1.txt "HAWKI_UTIL_DISTMAP_RAW"\n"
@@ -100,11 +96,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_util_gendist",
-                    "Distortion map creation",
+                    "(OBSOLETE) Distortion map creation",
                     hawki_util_gendist_description,
                     "Yves Jung",
                     PACKAGE_BUGREPORT,  
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_util_gendist_create,
                     hawki_util_gendist_exec,
                     hawki_util_gendist_destroy) ;
@@ -230,7 +226,7 @@ static int hawki_util_gendist
     int                    dim_y;
     
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(framelist)) {
+    if (hawki_dfs_set_groups_legacy(framelist)) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         return -1 ;
     }
@@ -487,6 +483,7 @@ static cpl_table * hawki_util_gendist_convert(const char * filename)
         return NULL ;
     }
     nbentries = 0 ;
+    setlocale(LC_NUMERIC, "C"); // Behaviour of sscanf depends on the locale
     while (fgets(line, 1024, in) != NULL) {
         if (line[0] != '#') {
             if (sscanf(line, "%lg %lg %d %d", 
